abacusai.pipeline_reference — AbacusAI documentation

# abacusai.pipeline_reference

## Classes

`PipelineReference` | A reference to a pipeline to the objects it is run on.

## Module Contents

class abacusai.pipeline_reference.PipelineReference(client, pipelineReferenceId=None, pipelineId=None, objectType=None, datasetId=None, modelId=None, deploymentId=None, batchPredictionDescriptionId=None, modelMonitorId=None, notebookId=None, featureGroupId=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A reference to a pipeline to the objects it is run on.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - pipelineReferenceId (str) – The id of the reference.

    - pipelineId (str) – The id of the pipeline for the reference.

    - objectType (str) – The object type of the reference.

    - datasetId (str) – The dataset id of the reference.

    - modelId (str) – The model id of the reference.

    - deploymentId (str) – The deployment id of the reference.

    - batchPredictionDescriptionId (str) – The batch prediction description id of the reference.

    - modelMonitorId (str) – The model monitor id of the reference.

    - notebookId (str) – The notebook id of the reference.

    - featureGroupId (str) – The feature group id of the reference.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict